@@ -43,7 +43,8 @@ Params::Callbacks - Make your subroutines accept blocking callbacks
     print Dumper( [@result_2] ), "\n";  # [1,2,4,8]
 
     # With multiple callbacks, result is transformed in multiple stages
-    my @result_3 = foo( 0, 1, 2, 3, callback { 0 + 2 ** $_ } callback { 0 + 10 * $_ });
+    my @result_3 = foo( 0, 1, 2, 3, callback { 0 + 2 ** $_ }
+                                    callback { 0 + 10 * $_ });
     print Dumper( [@result_3] ), "\n";  # [10,20,40,80];
 
 =head1 DESCRIPTION
@@ -53,6 +54,8 @@ callbacks. Perhaps you would like to allow the caller to accept your function's
 return value as is, or to intercept, change, eliminate, or otherwise process that
 result before it is finally returned.
 
+=head2 How callbacks are identified and processed
+
 Callbacks are passed to your function by placing them at the end of the call's
 argument list. This module provides you with a means to identify and separate any
 callbacks from your function's arguments. It also provides dispatchers that will
@@ -154,7 +157,7 @@ use Scalar::Util qw(blessed);
 use Carp qw(confess);
 use namespace::clean;
 
-our $VERSION = '2.002001';
+our $VERSION = '2.002002';
 $VERSION = eval $VERSION;
 our @ISA         = qw(Exporter);
 our @EXPORT_OK   = qw(callbacks callback);
@@ -162,13 +165,13 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK, ALL => \@EXPORT_OK );
 
 =head1 METHODS
 
-=over 2
+=cut
 
-=item B<new>
+=head2 new
 
 Takes a list of scalar values, strips away any trailing callbacks and returns
 a new list containing a blessed array reference (the callback chain) followed
-by any values from the original list that weren't callbacks. 
+by any values from the original list that weren't callbacks.
 
 A typical use case would be processing a function's argument list C<@_>:
 
@@ -178,17 +181,15 @@ A typical use case would be processing a function's argument list C<@_>:
         ...
     }
 
-It is also possible to pass in a pre-prepared callback chain instead of 
-individual callbacks, in which case that value will be returned as the callback 
-chain, without inspecting the list for individual callbacks E<mdash> this behaviour 
-is useful when the ability to efficiently forward callbacks onto a more deeply 
+It is also possible to pass in a pre-prepared callback chain instead of
+individual callbacks, in which case that value will be returned as the callback
+chain, without inspecting the list for individual callbacks E<mdash> this behaviour
+is useful when the ability to efficiently forward callbacks onto a more deeply
 nested call is required.
 
 The output list is packaged in such a way as to make parsing the argument list
 as easy as possible.
 
-=back
-
 =cut
 
 
@@ -216,9 +217,7 @@ sub new
     return ( bless( \@callbacks, $class ), @params );
 }
 
-=over 2
-
-=item B<transform>
+=head2 transform
 
 Transform a result set by passing it through all the stages of the callbacks
 pipeline. The transformation terminates if the result set is reduced to
@@ -226,8 +225,6 @@ nothing, and an empty result set is returned.
 
 Empty or not, this method always returns a list.
 
-=back
-
 =cut
 
 
@@ -247,9 +244,7 @@ sub transform
     return @data;
 }
 
-=over 2
-
-=item B<smart_transform>
+=head2 smart_transform
 
 Transform a result set by passing it through all the stages of the callbacks
 pipeline. The transformation terminates if the result set is reduced to
@@ -261,8 +256,6 @@ If a scalar is required, a scalar is returned. If the result set contains a
 single element then the value of that element will be returned, otherwise a
 count of the number of elements is returned.
 
-=back
-
 =cut
 
 
@@ -286,11 +279,16 @@ sub smart_transform
     return @data;
 }
 
-=head1 EXPORTED FUNCTIONS
+=head1 EXPORTS
 
-=over 2
+Nothing is exported by default.
 
-=item B<callbacks>
+The following functions are exported individually upon request; they may all be
+imported at once using the import tags C<:all> and C<:ALL>.
+
+=cut
+
+=head2 callbacks
 
 Takes a list of scalar values, strips away any trailing callbacks and returns
 a new list containing a blessed array reference (the callback chain) followed
@@ -309,17 +307,15 @@ imagined use case is in processing a function's argument list C<@_>:
         ...
     }
 
-It is also possible to pass in a pre-prepared callback chain instead of 
+It is also possible to pass in a pre-prepared callback chain instead of
 individual callbacks, in which case this function will return that value
-as its own callback chain, without inspecting the list for individual 
-callbacks. This behaviour is useful when forwarding callbacks onto a 
+as its own callback chain, without inspecting the list for individual
+callbacks. This behaviour is useful when forwarding callbacks onto a
 more deeply nested call.
 
 The output list is packaged in such a way as to make parsing the argument list
 as easy as possible.
 
-=back
-
 =cut
 
 
@@ -328,9 +324,7 @@ sub callbacks
     return __PACKAGE__->new(@_);
 }
 
-=over 2
-
-=item B<callback>
+=head2 callback
 
 A simple piece of syntactic sugar that announces a callback. The code
 reference it precedes is blessed as a C<Params::Callbacks::Callback>
@@ -343,8 +337,6 @@ separators:
     callback { ... }, callback { ... }, callback { ... }    # Valid
     callback { ... }  callback { ... }  callback { ... }    # Valid, too!
 
-=back
-
 =cut
 
 
